==> haskell-ap-normalize-0.1.0.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ap-normalize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ap-normalize
version:              0.1.0.0
visibility:           public
id:                   ap-normalize-0.1.0.0-9nJrF7dulHGGVwl5JkU0xD
key:                  ap-normalize-0.1.0.0-9nJrF7dulHGGVwl5JkU0xD
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  d08435e0a975cd076f9fc8d3b2d2c78a
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-8.10.2/site-local/ap-normalize-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/ap-normalize-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/ap-normalize-0.1.0.0
hs-libraries:         HSap-normalize-0.1.0.0-9nJrF7dulHGGVwl5JkU0xD
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ap-normalize-0.1.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ap-normalize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ap-normalize
version:              0.1.0.0
visibility:           public
id:                   ap-normalize-0.1.0.0-L9MyT9i7uGYDe89PNf6RRI
key:                  ap-normalize-0.1.0.0-L9MyT9i7uGYDe89PNf6RRI
license:              MIT
copyright:            Li-yao Xia 2020
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
synopsis:             Self-normalizing applicative expressions
description:
    An applicative functor transformer to normalize expressions using @(\<$>)@,
    @(\<*>)@, and @pure@ into a linear list of actions.
    See "ApNormalize" to get started.

category:             Control
abi:                  1891930a96945fe1efd007b58d6fa3a3
exposed:              True
exposed-modules:      ApNormalize ApNormalize.Aps ApNormalize.DList
import-dirs:          /usr/lib/ghc-8.10.3/site-local/ap-normalize-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/ap-normalize-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/ap-normalize-0.1.0.0
hs-libraries:         HSap-normalize-0.1.0.0-L9MyT9i7uGYDe89PNf6RRI
depends:              base-4.14.1.0
haddock-interfaces:
    /usr/share/doc/haskell-ap-normalize/html/ap-normalize.haddock

haddock-html:         /usr/share/doc/haskell-ap-normalize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
